Queries the camera's metadata from NIMS and constructs the URL to its timelapse video file (720p MP4). Issues a warning if timelapse is not enabled for the camera.
Queries the camera's metadata from NIMS and constructs the URL to its timelapse video file (720p MP4). Issues a warning if timelapse is not enabled for the camera.